/*!
@ng-dynamic-forms/ui-material 1.4.33 2017-10-01 11:48 UTC
Copyright (c) 2016-2017, Udo Schöfer http://www.udos86.de

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
import { ChangeDetectorRef, Component, ContentChildren, EventEmitter, Input, NgModule, Output, ViewChild, ViewChildren } from '@angular/core';
import { DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_SLIDER, DYNAMIC_FORM_CONTROL_TYPE_SWITCH, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DynamicFormComponent, DynamicFormControlComponent, DynamicFormValidationService, DynamicFormsCoreModule, DynamicTemplateDirective } from '@ng-dynamic-forms/core';
import { MatAutocompleteModule, MatCheckboxModule, MatDatepickerModule, MatInput, MatInputModule, MatRadioModule, MatSelectModule, MatSlideToggleModule, MatSliderModule } from '@angular/material';
import { CommonModule } from '@angular/common';
import { ReactiveFormsModule } from '@angular/forms';

var MAT_VIEW_CHILD_SELECTOR = "matAutocomplete,matCheckbox,matDatepicker,matInput,matRadioGroup,matSelect,\n    matSlider,matSlideToggle,matTextarea";

var __extends$1 = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var DynamicMaterialFormControlComponent = /** @class */ (function (_super) {
    __extends$1(DynamicMaterialFormControlComponent, _super);
    /**
     * @param {?} changeDetectorRef
     * @param {?} validationService
     */
    function DynamicMaterialFormControlComponent(changeDetectorRef, validationService) {
        var _this = _super.call(this, changeDetectorRef, validationService) || this;
        _this.changeDetectorRef = changeDetectorRef;
        _this.validationService = validationService;
        _this._showCharacterCount = false;
        _this.bindId = true;
        _this.context = null;
        _this.hasErrorMessaging = false;
        _this.blur = new EventEmitter();
        _this.change = new EventEmitter();
        _this.focus = new EventEmitter();
        return _this;
    }
    Object.defineProperty(DynamicMaterialFormControlComponent.prototype, "showCharacterHint", {
        /**
         * @return {?}
         */
        get: function () {
            return !!(this._showCharacterCount && ((this.model)).maxLength && this.characterCount);
        },
        /**
         * @param {?} value
         * @return {?}
         */
        set: function (value) {
            this._showCharacterCount = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} changes
     * @return {?}
     */
    DynamicMaterialFormControlComponent.prototype.ngOnChanges = function (changes) {
        _super.prototype.ngOnChanges.call(this, changes);
        if (changes["model"]) {
            this.type = DynamicMaterialFormControlComponent.getFormControlType(this.model);
        }
    };
    Object.defineProperty(DynamicMaterialFormControlComponent.prototype, "characterCount", {
        /**
         * @return {?}
         */
        get: function () {
            return this.matInput ? this.matInput.value.length : null;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} model
     * @return {?}
     */
    DynamicMaterialFormControlComponent.getFormControlType = function (model) {
        switch (model.type) {
            case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
                return 1 /* Array */;
            case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
                return 2 /* Checkbox */;
            case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
                return 4 /* Group */;
            case DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER:
                return 3 /* DatePicker */;
            case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
                return 5 /* Input */;
            case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
                return 6 /* RadioGroup */;
            case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
                return 7 /* Select */;
            case DYNAMIC_FORM_CONTROL_TYPE_SLIDER:
                return 8 /* Slider */;
            case DYNAMIC_FORM_CONTROL_TYPE_SWITCH:
                return 9 /* SlideToggle */;
            case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
                return 10 /* TextArea */;
            default:
                return null;
        }
    };
    DynamicMaterialFormControlComponent.decorators = [
        { type: Component, args: [{
                    selector: "dynamic-material-form-control,dynamic-form-material-control",
                    template: "<div [formGroup]=\"group\" [ngClass]=\"[model.cls.element.container, model.cls.grid.container]\"><label *ngIf=\"model.label && type !== 2\" [attr.for]=\"model.id\" [innerHTML]=\"model.label\" [ngClass]=\"[model.cls.element.label, model.cls.grid.label]\"></label><ng-container *ngIf=\"type !== 1 && template?.align === 'START'\"><ng-container *ngTemplateOutlet=\"template?.templateRef; context: model\"></ng-container></ng-container><ng-container [ngSwitch]=\"type\"><div *ngSwitchCase=\"1\" [dynamicId]=\"bindId && model.id\" [formArrayName]=\"model.id\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\"><div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\" [formGroupName]=\"idx\" [ngClass]=\"[model.cls.element.group, model.cls.grid.group]\"><dynamic-material-form-control *ngFor=\"let controlModel of groupModel.group\" [bindId]=\"false\" [context]=\"groupModel\" [group]=\"control.at(idx)\" [hasErrorMessaging]=\"controlModel.hasErrorMessages\" [model]=\"controlModel\" [templates]=\"templates\" [ngClass]=\"[controlModel.cls.element.host, controlModel.cls.grid.host]\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"></dynamic-material-form-control><ng-container *ngTemplateOutlet=\"template?.templateRef; context: groupModel\"></ng-container></div></div><mat-checkbox *ngSwitchCase=\"2\" #matCheckbox [checked]=\"model.checked\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [indeterminate]=\"model.indeterminate\" [labelPosition]=\"model.labelPosition\" [name]=\"model.name\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"><span [ngClass]=\"model.cls.element.label\" [innerHTML]=\"model.label\"></span></mat-checkbox><mat-form-field *ngSwitchCase=\"3\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\"><input matInput [autofocus]=\"model.autoFocus\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [max]=\"model.max\" [matDatepicker]=\"matDatepicker\" [min]=\"model.min\" [name]=\"model.name\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"><mat-datepicker-toggle matSuffix [for]=\"matDatepicker\"></mat-datepicker-toggle><mat-datepicker #matDatepicker [startAt]=\"model.focusedDate\" [touchUi]=\"true\" (selectedChanged)=\"onValueChange($event)\"></mat-datepicker></mat-form-field><div *ngSwitchCase=\"4\" role=\"group\" [dynamicId]=\"bindId && model.id\" [formGroupName]=\"model.id\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\"><dynamic-material-form-control *ngFor=\"let controlModel of model.group\" [group]=\"control\" [hasErrorMessaging]=\"controlModel.hasErrorMessages\" [model]=\"controlModel\" [templates]=\"templates\" [ngClass]=\"[controlModel.cls.element.host, controlModel.cls.grid.host]\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"></dynamic-material-form-control></div><ng-container *ngSwitchCase=\"5\"><mat-form-field #matInput [ngClass]=\"model.cls.grid.control\"><span *ngIf=\"model.prefix\" matPrefix [innerHTML]=\"model.prefix\"></span> <input matInput [attr.accept]=\"model.accept\" [attr.autoComplete]=\"model.autoComplete\" [attr.list]=\"model.listId\" [attr.max]=\"model.max\" [attr.min]=\"model.min\" [attr.multiple]=\"model.multiple\" [attr.step]=\"model.step\" [attr.tabindex]=\"model.tabIndex\" [autofocus]=\"model.autoFocus\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [maxlength]=\"model.maxLength\" [matAutocomplete]=\"matAutocomplete\" [minlength]=\"model.minLength\" [name]=\"model.name\" [ngClass]=\"model.cls.element.control\" [pattern]=\"model.pattern\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" [spellcheck]=\"model.spellCheck\" [type]=\"model.inputType\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"> <span *ngIf=\"model.suffix\" matSuffix [innerHTML]=\"model.suffix\"></span><mat-hint *ngIf=\"model.hint\" align=\"start\" [innerHTML]=\"model.hint\"></mat-hint><mat-hint *ngIf=\"showCharacterHint\" align=\"end\">{{characterCount}} / {{model.maxLength}}</mat-hint><mat-error *ngFor=\"let message of errorMessages\"><span *ngIf=\"showErrorMessages\">{{message}}</span></mat-error></mat-form-field><mat-autocomplete #matAutocomplete=\"matAutocomplete\"><mat-option *ngFor=\"let option of model.list\" [value]=\"option\">{{ option }}</mat-option></mat-autocomplete></ng-container><mat-radio-group *ngSwitchCase=\"6\" #matRadioGroup [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [name]=\"model.name\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"><mat-radio-button *ngFor=\"let option of model.options$ | async\" [labelPosition]=\"'after'\" [name]=\"model.name\" [ngClass]=\"model.cls.element.option\" [value]=\"option.value\"><span [innerHTML]=\"option.label\"></span></mat-radio-button></mat-radio-group><mat-select *ngSwitchCase=\"7\" #matSelect [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [multiple]=\"model.multiple\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\" [placeholder]=\"model.placeholder\" (change)=\"onValueChange($event)\"><mat-option *ngFor=\"let option of model.options$ | async\" [ngClass]=\"model.cls.element.option\" [value]=\"option.value\"><span [innerHTML]=\"option.label\"></span></mat-option></mat-select><mat-slider *ngSwitchCase=\"8\" #matSlider [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [min]=\"model.min\" [max]=\"model.max\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\" [step]=\"model.step\" [thumbLabel]=\"true\" tickInterval=\"1\" [vertical]=\"model.vertical\" (change)=\"onValueChange($event)\"></mat-slider><mat-slide-toggle *ngSwitchCase=\"9\" #matSlideToggle [checked]=\"model.checked\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [labelPosition]=\"model.labelPosition\" [name]=\"model.name\" [ngClass]=\"[model.cls.element.control, model.cls.grid.control]\" (change)=\"onValueChange($event)\"><span *ngIf=\"!model.checked\" [innerHTML]=\"model.offLabel\"></span> <span *ngIf=\"model.checked\" [innerHTML]=\"model.onLabel\"></span></mat-slide-toggle><mat-form-field *ngSwitchCase=\"10\" #matTextarea [ngClass]=\"model.cls.grid.control\"><textarea matInput [attr.tabindex]=\"model.tabIndex\" [dynamicId]=\"bindId && model.id\" [cols]=\"model.cols\" [formControlName]=\"model.id\" [maxlength]=\"model.maxLength\" [minlength]=\"model.minLength\" [name]=\"model.name\" [ngClass]=\"model.cls.element.control\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" [rows]=\"model.rows\" [spellcheck]=\"model.spellCheck\" [wrap]=\"model.wrap\" (blur)=\"onFocusChange($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocusChange($event)\"></textarea><mat-hint *ngIf=\"model.hint\" align=\"start\" [innerHTML]=\"model.hint\"></mat-hint><mat-hint *ngIf=\"showCharacterHint\" align=\"end\">{{characterCount}} / {{model.maxLength}}</mat-hint><mat-error *ngFor=\"let message of errorMessages\"><span *ngIf=\"showErrorMessages\">{{message}}</span></mat-error></mat-form-field></ng-container><ng-container *ngIf=\"type !== 5 && type !== 10 && showErrorMessages\"><mat-error *ngFor=\"let message of errorMessages\">{{message}}</mat-error></ng-container><ng-container *ngIf=\"type !== 1 && template?.align === 'END'\"><ng-container *ngTemplateOutlet=\"template?.templateRef; context: model\"></ng-container></ng-container></div>"
                },] },
    ];
    /**
     * @nocollapse
     */
    DynamicMaterialFormControlComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef, },
        { type: DynamicFormValidationService, },
    ]; };
    DynamicMaterialFormControlComponent.propDecorators = {
        'contentTemplates': [{ type: ContentChildren, args: [DynamicTemplateDirective,] },],
        'inputTemplates': [{ type: Input, args: ["templates",] },],
        'bindId': [{ type: Input },],
        'context': [{ type: Input },],
        'group': [{ type: Input },],
        'hasErrorMessaging': [{ type: Input },],
        'model': [{ type: Input },],
        'showCharacterHint': [{ type: Input },],
        'blur': [{ type: Output },],
        'change': [{ type: Output },],
        'focus': [{ type: Output },],
        'matViewChild': [{ type: ViewChild, args: [MAT_VIEW_CHILD_SELECTOR,] },],
        'matInput': [{ type: ViewChild, args: [MatInput,] },],
    };
    return DynamicMaterialFormControlComponent;
}(DynamicFormControlComponent));

var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var DynamicMaterialFormComponent = /** @class */ (function (_super) {
    __extends(DynamicMaterialFormComponent, _super);
    function DynamicMaterialFormComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.blur = new EventEmitter();
        _this.change = new EventEmitter();
        _this.focus = new EventEmitter();
        return _this;
    }
    DynamicMaterialFormComponent.decorators = [
        { type: Component, args: [{
                    selector: "dynamic-material-form",
                    template: "<dynamic-material-form-control *ngFor=\"let controlModel of model; trackBy: trackByFn\" [group]=\"group\" [hasErrorMessaging]=\"controlModel.hasErrorMessages\" [model]=\"controlModel\" [ngClass]=\"[controlModel.cls.element.host, controlModel.cls.grid.host]\" [showCharacterHint]=\"controlModel.type === 'INPUT'\" [templates]=\"templates\" (blur)=\"onEvent($event, 0)\" (change)=\"onEvent($event, 1)\" (focus)=\"onEvent($event, 2)\"></dynamic-material-form-control>"
                },] },
    ];
    /**
     * @nocollapse
     */
    DynamicMaterialFormComponent.ctorParameters = function () { return []; };
    DynamicMaterialFormComponent.propDecorators = {
        'group': [{ type: Input },],
        'model': [{ type: Input },],
        'blur': [{ type: Output },],
        'change': [{ type: Output },],
        'focus': [{ type: Output },],
        'templates': [{ type: ContentChildren, args: [DynamicTemplateDirective,] },],
        'components': [{ type: ViewChildren, args: [DynamicMaterialFormControlComponent,] },],
    };
    return DynamicMaterialFormComponent;
}(DynamicFormComponent));

var DynamicFormsMaterialUIModule = /** @class */ (function () {
    function DynamicFormsMaterialUIModule() {
    }
    DynamicFormsMaterialUIModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        MatAutocompleteModule,
                        MatCheckboxModule,
                        MatDatepickerModule,
                        MatInputModule,
                        MatRadioModule,
                        MatSelectModule,
                        MatSliderModule,
                        MatSlideToggleModule,
                        DynamicFormsCoreModule
                    ],
                    declarations: [
                        DynamicMaterialFormControlComponent,
                        DynamicMaterialFormComponent
                    ],
                    exports: [
                        DynamicFormsCoreModule,
                        DynamicMaterialFormControlComponent,
                        DynamicMaterialFormComponent
                    ]
                },] },
    ];
    /**
     * @nocollapse
     */
    DynamicFormsMaterialUIModule.ctorParameters = function () { return []; };
    return DynamicFormsMaterialUIModule;
}());

export { DynamicMaterialFormComponent, MAT_VIEW_CHILD_SELECTOR, DynamicMaterialFormControlComponent, DynamicFormsMaterialUIModule };
//# sourceMappingURL=ui-material.es.js.map
